package org.tapomay;

import java.sql.Connection;
import java.util.concurrent.BrokenBarrierException;
import java.util.concurrent.Callable;
import java.util.concurrent.CyclicBarrier;

/**
 * Throws QueryExecutionException if query execution fails on given client.
 * Performs a barrier await before throwing. Logs any other errors and returns
 * with the result.
 * 
 * @author tapomay
 * 
 */
public class MonetdbClientCallable implements Callable<Integer>
{
    private JdbcMonetdbTestClient monetdbClient;
    private String updateQuery;
    private CyclicBarrier barrier;
    private Connection connection;
    
    public MonetdbClientCallable(JdbcMonetdbTestClient monetdbClient,
                                 String updateQuery, CyclicBarrier barrier, Connection connection)
    {
        super();
        this.monetdbClient = monetdbClient;
        this.updateQuery = updateQuery;
        this.barrier = barrier;
        this.connection = connection;
    }

    @Override
    public Integer call()
    {
        Integer executeUpdate;
        
        try
        {
            executeUpdate = monetdbClient.executeUpdate(updateQuery, connection, false);
        }
        finally
        {
            try
            {
                barrier.await();
            }
            catch (InterruptedException e)
            {
            }
            catch (BrokenBarrierException e)
            {
            }
        }
        return executeUpdate;
    }
}
